@@ -38,12 +38,13 @@ from global_chem.medicinal_chemistry.scaffolds.common_r_group_replacements impor
 # Proteins Kinases
 
 from global_chem.proteins.kinases.braf.braf_inhibitors import BRAFInhibitors
-from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibtors import PrivilegedKinaseInhibitors
+from global_chem.proteins.kinases.scaffolds.privileged_kinase_inhibitors import PrivilegedKinaseInhibitors
 
 # Organic Synthesis
 
 from global_chem.organic_synthesis.solvents.common_organic_solvents import CommonOrganicSolvents
 from global_chem.organic_synthesis.protecting_groups.amino_acid_protecting_groups import AminoAcidProtectingGroups
+from global_chem.organic_synthesis.bidendate_phosphine_ligands.nickel_ligands import NickelBidendatePhosphineLigands
 
 # Narcotics
 
@@ -57,6 +58,10 @@ from global_chem.narcotics.schedule_five import ScheduleFive
 
 from global_chem.interstellar_space.interstellar_space import InterstellarSpace
 
+# Biopharmaceutics - Excipients
+
+from global_chem.formulation.excipients.biopharmaceutics_class_three.cimetidine_acyclovir import CimetidineAndAcyclovir
+
 # Miscellaneous
 
 from global_chem.miscellaneous.vitamins import Vitamins
